pygeodesy.azimuthal._AzimuthalBase

Package pygeodesy :: Module azimuthal :: Class _AzimuthalBase |
[frames] | no frames]

# Class _AzimuthalBase

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
                      _AzimuthalBase

Known Subclasses:
  - Equidistant
  - , _AzimuthalGeodesic
  - , Gnomonic
  - , LambertEqualArea
  - , Orthographic
  - , Stereographic

(INTERNAL) Base class for azimuthal projections.

See Also: Karney's C++ class AzimuthalEquidistant and Gnomonic or the `PyGeodesy` versions thereof EquidistantKarney respectively GnomonicKarney.

Instance Methods
__init__(self, lat0, lon0, datum=None, **name) New azimuthal projection. |
forward(self, lat, lon, **name) Must be overloaded. |
reset(self, lat0, lon0) Set or reset the center point of this azimuthal projection. |
reverse(self, x, y, **name_LatLon_and_kwds) Must be overloaded. |
toRepr(self, prec=6, **unused) Return a string representation of this projection. |
toStr(self, prec=6, sep=' ', **unused) Return a string representation of this projection. |
Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| datum Get the datum (Datum).
| equatoradius Get the geodesic's equatorial radius, semi-axis (`meter`).
| a Get the geodesic's equatorial radius, semi-axis (`meter`).
| flattening Get the geodesic's flattening (`scalar`).
| f Get the geodesic's flattening (`scalar`).
| lat0 Get the center latitude (`degrees90`).
| latlon0 Get the center lat- and longitude (LatLon2Tuple`(lat, lon)`) in (`degrees90`, `degrees180`).
| lon0 Get the center longitude (`degrees180`).
| majoradius DEPRECATED, use property `equatoradius`.
| radius Get this projection's mean radius of curvature (`meter`).
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, lat0, lon0, datum=None, **name) (Constructor) |
New azimuthal projection. Arguments: `lat0` - Latitude of the center point (`degrees90`). `lon0` - Longitude of the center point (`degrees180`). `datum` - Optional datum or ellipsoid (Datum, Ellipsoid, Ellipsoid2 or a_f2Tuple) or scalar earth radius (`meter`). `name` - Optional `name=NN` for the projection (`str`). Raises: `AzimuthalError` - Invalid `lat0` or `lon0` or (spherical) `datum`. `TypeError` - Invalid `datum`. Overrides: object.__init__

### reset (self, lat0, lon0) |
Set or reset the center point of this azimuthal projection. Arguments: `lat0` - Center point latitude (`degrees90`). `lon0` - Center point longitude (`degrees180`). Raises: `AzimuthalError` - Invalid `lat0` or `lon0`.

### toRepr (self, prec=6, **unused) |
Return a string representation of this projection. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). Returns: This projection as `"<classname>(lat0, lon0, ...)"` (`str`). Overrides: named._Named.toRepr

### toStr (self, prec=6, sep=' ', **unused) |
Return a string representation of this projection. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). `sep` - Separator to join (`str`). Returns: This projection as `"lat0 lon0"` (`str`). Overrides: named._Named.toStr

Property Details

### datum Get the datum (Datum). Get method: datum(self) - Get the datum (Datum). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### equatoradius Get the geodesic's equatorial radius, semi-axis (`meter`). Get method: equatoradius(self) - Get the geodesic's equatorial radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### a Get the geodesic's equatorial radius, semi-axis (`meter`). Get method: equatoradius(self) - Get the geodesic's equatorial radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### flattening Get the geodesic's flattening (`scalar`). Get method: flattening(self) - Get the geodesic's flattening (`scalar`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### f Get the geodesic's flattening (`scalar`). Get method: flattening(self) - Get the geodesic's flattening (`scalar`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lat0 Get the center latitude (`degrees90`). Get method: lat0(self) - Get the center latitude (`degrees90`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlon0 Get the center lat- and longitude (LatLon2Tuple`(lat, lon)`) in (`degrees90`, `degrees180`). Get method: latlon0(self) - Get the center lat- and longitude (LatLon2Tuple`(lat, lon)`) in (`degrees90`, `degrees180`). Set method: latlon0(self, latlon0) - Set the center lat- and longitude (`LatLon`, LatLon2Tuple or LatLon4Tuple).

### lon0 Get the center longitude (`degrees180`). Get method: lon0(self) - Get the center longitude (`degrees180`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### majoradius DEPRECATED, use property `equatoradius`. Get method: majoradius(self) - DEPRECATED, use property `equatoradius`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### radius Get this projection's mean radius of curvature (`meter`). Get method: radius(self) - Get this projection's mean radius of curvature (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.